@@ -211,6 +211,7 @@ void on_eject_activate (GtkMenuItem *item, gpointer user_data)
   /* first make sure we're not playing */
   stop_playback ();
 
+  nautilus_burn_drive_unlock (drive);
   nautilus_burn_drive_eject (drive);
 }
 
@@ -322,6 +323,9 @@ static void update_ui_for_album (AlbumDetails *album)
   char* duration_text;
   total_no_of_tracks=0;
 
+  /* Really really make sure we don't have a playing title */
+  sj_main_set_title (NULL);
+
   if (album == NULL) {
     gtk_list_store_clear (track_store);
     gtk_entry_set_text (GTK_ENTRY (title_entry), "");
@@ -336,7 +340,7 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_widget_set_sensitive (extract_button, FALSE);
     gtk_widget_set_sensitive (extract_menuitem, FALSE);
     gtk_widget_set_sensitive (select_all_menuitem, FALSE);
-    gtk_widget_set_sensitive (deselect_all_menuitem, TRUE);
+    gtk_widget_set_sensitive (deselect_all_menuitem, FALSE);
     gtk_widget_set_sensitive (prev_menuitem, FALSE);
     gtk_widget_set_sensitive (next_menuitem, FALSE);
   } else {
@@ -348,6 +352,8 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_entry_set_text (GTK_ENTRY (artist_entry), album->artist);
     g_signal_handlers_unblock_by_func (title_entry, on_title_edit_changed, NULL);
     g_signal_handlers_unblock_by_func (artist_entry, on_artist_edit_changed, NULL);
+    /* Clear the genre field, it's from the user */
+    gtk_entry_set_text (GTK_ENTRY (genre_entry), "");
 
     gtk_widget_set_sensitive (title_entry, TRUE);
     gtk_widget_set_sensitive (artist_entry, TRUE);
@@ -417,7 +423,7 @@ AlbumDetails* multiple_album_dialog(GList *albums)
 
   if (dialog == NULL) {
     GtkTreeViewColumn *column;
-    GtkCellRenderer *text_renderer = text_renderer = gtk_cell_renderer_text_new ();
+    GtkCellRenderer *text_renderer = gtk_cell_renderer_text_new ();
 
     dialog = glade_xml_get_widget (glade, "multiple_dialog");
     g_assert (dialog != NULL);
@@ -525,7 +531,7 @@ void paranoia_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry,
     sj_extractor_set_paranoia (extractor, DEFAULT_PARANOIA);
   } else {
     int value = gconf_value_get_int (entry->value);
-    if (value == 0 || value == 4 || value == 255) {
+    if (value == 0 || value == 2 || value == 4 || value == 8 || value == 16 || value == 255) {
       sj_extractor_set_paranoia (extractor, value);
     }
   }
@@ -742,7 +748,7 @@ set_drive_from_device (const char *device)
 
   if (! device)
     return;
-
+  
   drive = nautilus_burn_drive_new_from_path (device);
   g_assert (drive);
 
@@ -1008,7 +1014,9 @@ static void on_extract_toggled (GtkCellRendererToggle *cellrenderertoggle,
 {
   gboolean extract;
   GtkTreeIter iter;
-  gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path);
+
+  if (!gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path))
+      return;
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), &iter, COLUMN_EXTRACT, &extract, -1);
   /* extract is the old state here, so toggle */
   extract = !extract;
@@ -1053,7 +1061,9 @@ static void on_cell_edited (GtkCellRendererText *renderer,
   GtkTreeIter iter;
   TrackDetails *track;
   char *artist, *title;
-  gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path);
+
+  if (!gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (track_store), &iter, path))
+    return;
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), &iter,
                       COLUMN_ARTIST, &artist,
                       COLUMN_TITLE, &title,
@@ -1118,6 +1128,7 @@ void on_genre_edit_changed(GtkEditable *widget, gpointer user_data) {
 void on_contents_activate(GtkWidget *button, gpointer user_data) {
   GError *error = NULL;
 
+  /* If/when we drop libgnome, simply spawn the URI ghelp:sound-juicer. */
   gnome_help_display ("sound-juicer", NULL, &error);
   if (error) {
     GtkWidget *dialog;
@@ -1213,6 +1224,7 @@ on_message_received (const char *message, gpointer user_data)
 
 int main (int argc, char **argv)
 {
+  GnomeProgram *program;
   GError *error = NULL;
   GtkTreeSelection *selection;
   char *device = NULL;
@@ -1227,24 +1239,25 @@ int main (int argc, char **argv)
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
-  
-  g_set_application_name (_("Sound Juicer"));
-  
+
   ctx = g_option_context_new ("- Sound Juicer");
   g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
-  g_option_context_add_group (ctx, gtk_get_option_group (FALSE));
   g_option_context_add_group (ctx, gst_init_get_option_group ());
-  if (!g_option_context_parse (ctx, &argc, &argv, &error)) {
-    g_critical ("Failed to initialize: %s\n", error->message);
-    g_error_free (error);
-    return 1;
-  }
+  g_option_context_set_ignore_unknown_options (ctx, TRUE);
+
+  program = gnome_program_init ("sound-juicer", 	 
+                      VERSION, LIBGNOMEUI_MODULE, 	 
+                      argc, argv, 	 
+                      GNOME_PROGRAM_STANDARD_PROPERTIES,
+                      GNOME_PARAM_GOPTION_CONTEXT, ctx,
+                      NULL);
+
+  g_set_application_name (_("Sound Juicer"));
 
-  gtk_init (&argc, &argv);
   sj_stock_init ();
 
-  gtk_window_set_default_icon_from_file (PIXMAPDIR"/sound-juicer.png", NULL);
-
+  gtk_window_set_default_icon_name ("sound-juicer");
+  
   connection = bacon_message_connection_new ("sound-juicer");
   if (bacon_message_connection_get_is_server (connection) == FALSE) {
 	  bacon_message_connection_send (connection, RAISE_WINDOW);
@@ -1318,6 +1331,27 @@ int main (int argc, char **argv)
   prev_menuitem = glade_xml_get_widget (glade, "previous_track_menuitem");
   status_bar = glade_xml_get_widget (glade, "status_bar");
 
+  { /* ensure that the play/pause button's size is constant */
+    GtkWidget *fake_button1, *fake_button2;
+    GtkSizeGroup *size_group;
+
+    size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
+    fake_button1 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
+    gtk_size_group_add_widget (size_group, fake_button1);
+    g_signal_connect_swapped (play_button, "destroy",
+		    	      G_CALLBACK (gtk_widget_destroy),
+			      fake_button1);
+
+    fake_button2 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE);
+    gtk_size_group_add_widget (size_group, fake_button2);
+    g_signal_connect_swapped (play_button, "destroy",
+		    	      G_CALLBACK (gtk_widget_destroy),
+			      fake_button2);
+
+    gtk_size_group_add_widget (size_group, play_button);
+  }
+
   {
     GtkEntryCompletion *completion;
     completion = gtk_entry_completion_new ();
@@ -1339,7 +1373,7 @@ int main (int argc, char **argv)
                                                        toggle_renderer,
                                                        "active", COLUMN_EXTRACT,
                                                        NULL);
-    gtk_tree_view_column_set_resizable (column, TRUE);
+    gtk_tree_view_column_set_resizable (column, FALSE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (track_listview), column);
 
     column = gtk_tree_view_column_new ();
@@ -1381,7 +1415,7 @@ int main (int argc, char **argv)
     column = gtk_tree_view_column_new_with_attributes (_("Duration"),
                                                        renderer,
                                                        NULL);
-    gtk_tree_view_column_set_resizable (column, TRUE);
+    gtk_tree_view_column_set_resizable (column, FALSE);
     gtk_tree_view_column_set_cell_data_func (column, renderer, duration_cell_data_cb, NULL, NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (track_listview), column);
   }
@@ -1394,11 +1428,15 @@ int main (int argc, char **argv)
   }
 
   update_ui_for_album (NULL);
-  gconf_bridge_bind_window_size(gconf_bridge_get(), GCONF_WINDOW, GTK_WINDOW (main_window));
-  gtk_widget_show (main_window);
 
   sj_play_init ();
 
+#if HAVE_TAGLIB
+  /* See if the system supports id3mux, and if not register our own */
+  if (!gst_default_registry_check_feature_version ("id3mux", 0, 10, 0))
+    id3mux_register ();
+#endif
+
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (track_listview));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
@@ -1421,9 +1459,13 @@ int main (int argc, char **argv)
     return 0;
   }
 
+  gconf_bridge_bind_window_size(gconf_bridge_get(), GCONF_WINDOW, GTK_WINDOW (main_window));
+  gtk_widget_show (main_window);
   gtk_main ();
+
   g_object_unref (metadata);
   g_object_unref (extractor);
   g_object_unref (gconf_client);
+  g_object_unref (program);
   return 0;
 }
